@@ -42,9 +42,6 @@ extern "C"
 #define TDS_STATIC_CAST(type, a) ((type)(a))
 #endif
 
-static const char rcsid_sybdb_h[] = "$Id: sybdb.h,v 1.106 2011-12-05 02:26:31 jklowden Exp $";
-static const void *const no_unused_sybdb_h_warn[] = { rcsid_sybdb_h, no_unused_sybdb_h_warn };
-
 #ifdef FALSE
 #undef FALSE
 #endif
@@ -76,9 +73,9 @@ static const void *const no_unused_sybdb_h_warn[] = { rcsid_sybdb_h, no_unused_s
 #define DBVERSION_42      3
 #define DBVERSION_70      4
 #define DBVERSION_71      5
-#define DBVERSION_80      DBVERSION_71
 #define DBVERSION_72      6
 #define DBVERSION_73      7
+#define DBVERSION_74      8
 
 /* these two are defined by Microsoft for dbsetlversion() */
 #define DBVER42 	  DBVERSION_42
@@ -97,11 +94,13 @@ static const void *const no_unused_sybdb_h_warn[] = { rcsid_sybdb_h, no_unused_s
 #define DBTDS_4_9_5             6	/* 4.9.5 (NCR) SQL Server */
 #define DBTDS_5_0               7	/* 5.0 SQL Server */
 #define DBTDS_7_0               8	/* Microsoft SQL Server 7.0 */
-#define DBTDS_8_0               9	/* Microsoft SQL Server 2000 */
-#define DBTDS_9_0               10	/* Microsoft SQL Server 2005 */
+#define DBTDS_8_0               ("Use DBTDS_7_1 instead"*x)	/* Microsoft SQL Server 2000 */
+#define DBTDS_9_0               ("Use DBTDS_7_2 instead"*x)	/* Microsoft SQL Server 2005 */
 #define DBTDS_7_1               9	/* Microsoft SQL Server 2000 */
 #define DBTDS_7_2               10	/* Microsoft SQL Server 2005 */
 #define DBTDS_7_3               11	/* Microsoft SQL Server 2008 */
+#define DBTDS_7_4               12	/* Microsoft SQL Server 2012/2014 */
+#define DBTDS_8_0_              13	/* Microsoft SQL Server 2022 */
 
 #define DBTXPLEN 16
 
@@ -151,7 +150,7 @@ typedef int BOOL;
 #endif
 #endif
 
-#ifndef _tds_h_
+#ifndef _tdsguard_hfOrWb5znoUCWdBPoNQvqN_
 /* copied from tds.h */
 /* TODO find a best way... */
 enum
@@ -210,6 +209,14 @@ enum
 #define SYBDATETIMN	SYBDATETIMN
 	SYBNVARCHAR = 103,	/* 0x67 */
 #define SYBNVARCHAR	SYBNVARCHAR
+	SYBDATE = 49,		/* 0x31 */
+#define SYBDATE SYBDATE
+	SYBTIME = 51,		/* 0x33 */
+#define SYBTIME SYBTIME
+	SYBBIGDATETIME = 187,	/* 0xBB */
+#define SYBBIGDATETIME SYBBIGDATETIME
+	SYBBIGTIME = 188,	/* 0xBC */
+#define SYBBIGTIME SYBBIGTIME
 	SYBMSDATE = 40,		/* 0x28 */
 #define SYBMSDATE SYBMSDATE
 	SYBMSTIME = 41,		/* 0x29 */
@@ -243,15 +250,15 @@ typedef unsigned char DBBOOL;
 typedef char DBCHAR;
 typedef unsigned char DBBIT;
 typedef unsigned char DBTINYINT;
-typedef tds_sysdep_int16_type DBSMALLINT;
-typedef tds_sysdep_int32_type DBINT;
-typedef tds_sysdep_int64_type DBBIGINT;
+typedef int16_t DBSMALLINT;
+typedef int32_t DBINT;
+typedef int64_t DBBIGINT;
 typedef unsigned char DBBINARY;
 typedef tds_sysdep_real32_type DBREAL;
 typedef tds_sysdep_real64_type DBFLT8;
-typedef unsigned tds_sysdep_int16_type DBUSMALLINT;
-typedef unsigned tds_sysdep_int32_type DBUINT;
-typedef unsigned tds_sysdep_int64_type DBUBIGINT;
+typedef uint16_t DBUSMALLINT;
+typedef uint32_t DBUINT;
+typedef uint64_t DBUBIGINT;
 
 typedef struct 
 {
@@ -277,7 +284,7 @@ typedef DBNUMERIC DBDECIMAL;
 typedef struct
 {
 	DBINT mnyhigh;
-	unsigned tds_sysdep_int32_type mnylow;
+	DBUINT mnylow;
 } DBMONEY;
 
 typedef struct
@@ -303,6 +310,8 @@ typedef struct
 	DBINT      date;	/**< date, 0 = 1900-01-01 */
 	DBSMALLINT offset;	/**< time offset */
 	DBUSMALLINT time_prec:3;
+/* fix a problem with some public headers defining _res */
+#undef _res
 	DBUSMALLINT _res:10;
 	DBUSMALLINT has_time:1;
 	DBUSMALLINT has_date:1;
@@ -554,12 +563,17 @@ typedef int (*MHANDLEFUNC) (DBPROCESS * dbproc, DBINT msgno, int msgstate, int s
 #define DECIMALBIND       18
 #define SRCNUMERICBIND    19
 #define SRCDECIMALBIND    20
+#define DATEBIND          21
+#define TIMEBIND          22
+#define BIGDATETIMEBIND   23
+#define BIGTIMEBIND       24
 #define BIGINTBIND        30
 #define DATETIME2BIND     31
 #define MAXBINDTYPES      32	/* keep last */
 
 #define DBPRCOLSEP  21
 #define DBPRLINELEN 22
+#define DBRPCNORETURN 0
 #define DBRPCRETURN 1
 #define DBRPCDEFAULT 2
 
@@ -662,8 +676,6 @@ int dbtabcount(DBPROCESS * dbprocess);
 char *dbtabname(DBPROCESS * dbprocess, int tabnum);
 char *dbtabsource(DBPROCESS * dbprocess, int colnum, int *tabnum);
 
-RETCODE dbsetlshort(LOGINREC * login, int value, int which);
-
 RETCODE dbsendpassthru(DBPROCESS * dbprocess, DBVOIDPTR bufp);
 RETCODE dbrecvpassthru(DBPROCESS * dbprocess, DBVOIDPTR * bufp);
 
@@ -723,6 +735,7 @@ RETCODE dbtablecolinfo (DBPROCESS *dbproc, DBINT column, DBCOL *pdbcol );
 RETCODE	dbcolinfo (DBPROCESS *dbproc, CI_TYPE type, DBINT column, DBINT computeid, DBCOL *pdbcol);
 DBINT dbcollen(DBPROCESS * dbproc, int column);
 char *dbcolname(DBPROCESS * dbproc, int column);
+const char *dbacolname(DBPROCESS * dbproc, int computeid, int column);
 char *dbcolsource(DBPROCESS * dbproc, int colnum);
 int dbcoltype(DBPROCESS * dbproc, int column);
 DBTYPEINFO *dbcoltypeinfo(DBPROCESS * dbproc, int column);
@@ -1228,6 +1241,7 @@ RETCODE dbwritetext(DBPROCESS * dbproc, char *objname, DBBINARY * textptr, DBTIN
 /* LOGINREC manipulation */
 RETCODE dbsetlname(LOGINREC * login, const char *value, int which);
 RETCODE dbsetlbool(LOGINREC * login, int value, int which);
+RETCODE dbsetlshort(LOGINREC * login, int value, int which);
 RETCODE dbsetllong(LOGINREC * login, long value, int which);
 RETCODE dbsetlversion (LOGINREC * login, BYTE version);
 
@@ -1272,6 +1286,25 @@ RETCODE dbsetlversion (LOGINREC * login, BYTE version);
 #define DBSETDBNAME		14
 #define DBSETLDBNAME(x,y)	dbsetlname((x), (y), DBSETDBNAME)
 #define DBSETLVERSION(login, version) dbsetlversion((login), (version))
+#define DBSETNETWORKAUTH	101
+#define DBSETLNETWORKAUTH(x, y)	dbsetlbool((x), (y), DBSETNETWORKAUTH)
+#define DBSETMUTUALAUTH		102
+#define DBSETLMUTUALAUTH(x, y)	dbsetlbool((x), (y), DBSETMUTUALAUTH)
+#define DBSETSERVERPRINCIPAL	103
+#define DBSETLSERVERPRINCIPAL(x,y)	dbsetlname((x), (y), DBSETSERVERPRINCIPAL)
+/* settings from here are purely FreeTDS extensions */
+#define DBSETUTF16		1001
+#define DBSETLUTF16(x,y)	dbsetlbool((x), (y), DBSETUTF16)
+#define DBSETNTLMV2		1002
+#define DBSETLNTLMV2(x,y)	dbsetlbool((x), (y), DBSETNTLMV2)
+#define DBSETREADONLY		1003
+#define DBSETLREADONLY(x,y)	dbsetlbool((x), (y), DBSETREADONLY)
+#define DBSETDELEGATION		1004
+#define DBSETLDELEGATION(x, y)	dbsetlbool((x), (y), DBSETDELEGATION)
+#define DBSETENCRYPTION		1005
+#define DBSETLENCRYPTION(x, y)  dbsetlname((x), (y), DBSETENCRYPTION)
+#define DBSETPORT 		1006
+#define DBSETLPORT(x,y) 	dbsetlshort((x), (y), DBSETPORT)
 
 RETCODE bcp_init(DBPROCESS * dbproc, const char *tblname, const char *hfile, const char *errfile, int direction);
 DBINT bcp_done(DBPROCESS * dbproc);
